*     *****************************************************************
*     ***************************************************************** 
* 		File-Name:      replication_VolIII_chapter3.do       	                 
*   	Date:           October 10 2017                                 
*     	Author:         LH/ BC	                                          
*     	Purpose:        Create tables and figures for chapter 3 + appendix 3: MIA tables                 
*    	Input File:     DP_volIII_sept2017.dta (version Sept 2017)                                           
*     	Output File:    various			                         
*     	Data Output:    various                                            
*     	Previous file:  None                                            
*     	Machine:        	                                      
*     ****************************************************************  
*     ****************************************************************  

***NOTE TO USER: statistics produced by using the most recent dataset diverge slightly from this in the book//
*because we corrected minor errors and added scores for the International Coffee Organization (ICO) and EURAMET

use "DP_volIII_sept2017.dta",clear

* FIGURE 3.6. Divide the horizontal box plots in two groups for DELEGATION

sort ioname
by ioname: egen med=median(delegation)
gen group=0
///Use 38 IOs ordered by median values of delegation for each graph
tabstat med if end==1, stats (p50)
   variable |       p50
-------------+----------
         med |  .1656746
------------------------
replace group=1 if med>.1656746  

**Horizontal boxplots with outside values: 
graph hbox delegation if group==0, scheme(lean2) over(ioname, label(labsize(vsmall)) sort(1)) ///
ytitle(Delegation score (0-1))  ylabel(0(0.1)0.7)
graph save 3, replace
graph hbox delegation if group==1, scheme(lean2) over(ioname, label(labsize(vsmall)) sort(1)) ///
ytitle(Delegation score (0-1)) ylabel(0(0.1)0.7)
graph save 4, replace
 
*Save graphs in working directory then combine them
graph combine 3.gph 4.gph,  saving(figure36) graphregion(fcolor(white))
graph export figure36.tif, replace width(1800)

*FIGURE 3.10: Divide the horizontal box plots in two groups for POOLING

sort ioname
by ioname: egen med_p=median(pooling)
gen group_p=0
///Use 38 IOs ordered by median values of delegation for each graph
tabstat med_p if end==1, stats (p50)
   variable |       p50
-------------+----------
       med_p |  .2167708
------------------------
replace group_p=1 if med_p>.2167708

**Horizontal boxplots with outside values
graph hbox pooling if group_p==0, scheme(lean2) over(ioname, label(labsize(vsmall)) sort(1)) ///
ytitle(Pooling score (0-1)) graphregion(fcolor(white)) ylabel(0(0.1)0.8)
graph save 1, replace
graph hbox pooling if group_p==1, scheme(lean2) over(ioname, label(labsize(vsmall)) sort(1)) ///
ytitle(Pooling score (0-1)) graphregion(fcolor(white)) ylabel(0(0.1)0.8)
graph save 2, replace

*Save graphs in working directory then combine them
graph combine 1.gph 2.gph, saving(figure310) graphregion(fcolor(white))
*Save graphs in working directory then combine them
graph export figure310.tif,replace width(1800)

*FIGURES 3.1, 3.2, 3.3., 3.7

//Identify first and last occurrences systematically in each IO panel to construct graphs
by ionumber, sort: egen lasttime = max(cond(delegation >=0, year, .))
gen byte last = year == lasttime

by ionumber, sort: egen firsttime = min(cond(delegation >=0, year, .))
gen byte first = year == firsttime

tab ioname if firsttime <=1975&lasttime==2010
summ pooling delegation if firsttime <=1975&lasttime==2010
 
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
     pooling |      2,787    .3063394    .1864706          0   .7283334
  delegation |      2,787    .1840552    .1317292          0   .6519957

gen constantIO=1 if firsttime <=1975&lasttime==2010

egen number = count(ionumber), by(year) //generate count variable for number of IO for each year

*Collapse by 1-yr periods
collapse (mean)  delaccess delsuspens delconstit delbudget delfincompl delpolicy  ///
DS_sum_st delegation pooling poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy ///
 (last) inception ionumber ioname number if constantIO==1, by(year )
tsset year

*Times-series graphs for delegation, aggregate with bars for nr of IOs
twoway (tsline number, recast(bar) yaxis(2) fintensity(20) ) (tsline delegation) if year>=1975 ,  tscale(range(1975 2010)) ///
ytitle(Delegation) ytitle(Number of IOs, axis(2)) legend(order(1 "Number of IOs" 2 "Mean delegation score" )) ///
tlabel(#10) yscale(range(50 76) axis(2)) yscale(alt axis(2)) yscale(alt) scheme(s2mono) ///
ylabel(, angle(horizontal)) ylabel(, angle(horizontal) axis(2)) graphregion(fcolor(white)) xtitle("")

**Figure 3.1: Delegation (1975-2010)
graph save figure31, replace
graph export figure31.tif, width(1800)

*Times-series graphs for pooling, aggregate with bars for nr of IOs
twoway (tsline number, recast(bar) yaxis(2) fintensity(20) ) (tsline pooling) if year>=1975 ,  tscale(range(1975 2010)) ///
ytitle(Pooling) ytitle(Number of IOs, axis(2)) legend(order(1 "Number of IOs" 2 "Mean pooling score" )) ///
tlabel(#10) yscale(range(50 76) axis(2)) yscale(alt axis(2)) yscale(alt) scheme(s2mono) ///
ylabel(, angle(horizontal)) ylabel(, angle(horizontal) axis(2)) graphregion(fcolor(white)) xtitle("")

**Figure 3.2: Pooling (1975-2010)
graph save figure32, replace
graph export figure32.tif, width(1800)

**Figure 3.3: Delegation by decision area (1975-2010)
//Line graph for all dimensions of delegation
twoway (tsline delsuspens, lpattern(longdash_dot)) ///
(tsline delconstit) (tsline delbudget) ///
(tsline delfincompl, lpattern(solid)) ///
 (tsline delaccess) (tsline delpolicy)  if  year>=1975, ///
 ytitle(Delegation) ytitle(, margin(small))  ///
 ttitle(, margin(small)) tscale(range(1975 2010)) tlabel(#10) ///
  legend(order(1 "Suspension" 2 "Constitutional reform" 3 "Budgetary allocation" ///
 4 "Financial compliance" 5 "Accession" 6 "Policy making" ) size(small)) scheme(lean1) xtitle("")

 graph save figure33, replace
 graph export figure33.tif, width(1800)

 **Figure 3.7: Pooling by decision area (1975-2010)
//Line graph for all dimensions of pooling
twoway (tsline poolsuspens, lpattern(longdash_dot)) ///
 (tsline poolconstit) (tsline poolbudget) (tsline poolcompliance, lpattern(solid)) ///
 (tsline poolaccess) (tsline poolpolicy) if  year>=1975, ///
 ytitle(Pooling) ytitle(, margin(small))  ///
 ttitle(, margin(small)) tscale(range(1975 2010)) tlabel(#10) ///
 legend(order(1 "Suspension" 2 "Constitutional reform" 3 "Budgetary allocation" ///
 4 "Financial compliance" 5 "Accession" 6 "Policy making" ) size(small)) scheme(lean1) xtitle("")

 graph save figure37, replace
 graph export figure37.tif, width(1800)
 
 *TABLE 3.4: Correlation matrix: TABLE 3.4
use "DP_volIII_sept2017.dta", clear
 *DELEGATION
pca delaccess delsuspens delconstit delbudget delfincompl delpolicy, components(1) 
predict pca
alpha delaccess delsuspens delconstit delbudget delfincompl delpolicy, gen (alpha)
correl delegation pca alpha
*POOLING
pca poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy , components(1) 
predict pca_p
alpha poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy, gen (alpha_p)
correl pooling pca_p alpha_p
correl delegation pca pooling pca_p 

(obs=3,366)

             | delega~n      pca  pooling    pca_p
-------------+------------------------------------
  delegation |   1.0000
         pca |   0.9991   1.0000
     pooling |   0.2263   0.2291   1.0000
       pca_p |   0.2347   0.2372   0.9967   1.0000

correl pca pooling pca_p alpha_p

*Table 3.3: Factor analysis
pca delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy, components(2) 
rotate, promax

Principal components/correlation                 Number of obs    =      3,366
                                                 Number of comp.  =          2
                                                 Trace            =         12
    Rotation: oblique promax (Kaiser off)        Rho              =     0.6089

    --------------------------------------------------------------------------
       Component |     Variance   Proportion     Rotated comp. are correlated
    -------------+------------------------------------------------------------
           Comp1 |      4.26582       0.3555
           Comp2 |      3.00808       0.2507
    --------------------------------------------------------------------------

Rotated components 

    ------------------------------------------------
        Variable |    Comp1     Comp2 | Unexplained 
    -------------+--------------------+-------------
       delaccess |   0.4213   -0.0510 |       .2682 
      delsuspens |   0.3793    0.0566 |       .3321 
      delconstit |   0.4396   -0.0216 |       .1849 
       delbudget |   0.4104   -0.0142 |       .2858 
     delfincompl |   0.3475    0.0626 |       .4289 
       delpolicy |   0.4257   -0.0290 |       .2407 
      poolaccess |   0.0089    0.4384 |       .4077 
     poolsuspens |   0.0176    0.3667 |       .5775 
     poolconstit |  -0.0019    0.4245 |        .453 
    poolcompli~e |   0.0290    0.4688 |       .3026 
      poolbudget |  -0.1131    0.4345 |       .4607 
      poolpolicy |   0.0373    0.2716 |        .751 
    ------------------------------------------------

*TABLE 3.5 AND 3.6: Descriptive stats
tabstat delaccess delsuspens delconstit ///
delbudget delfincompl delpolicy del_agenda del_final DS_sum_st delegation, stats ///
(mean p50 cv min max p25 p75)

   stats |  delacc~s  delsus~s  delcon~t  delbud~t  delfin~l  delpol~y  del_ag~a  del_fi~l  DS_sum~t  delega~n
---------+----------------------------------------------------------------------------------------------------
    mean |  .1383219  .1085949  .1280535  .3175958  .1308557  .2684391   .231399  .0496133  .2649181  .1819768
     p50 |  .1428571  .1190476  .1190476  .3333333  .1190476  .2539683  .2083333         0         0  .1746032
      cv |  1.153211  1.127834  1.118721  .6261153  1.143222  .6412091  .6382461  2.200772  1.103576  .7283759
     min |         0         0         0         0         0         0         0         0         0         0
     max |  .7777778  .6428571  .6444445         1  .6666667  .9333333     .7075       .55         1  .6519957
     p25 |         0         0         0  .1666667         0  .1666667  .1388889         0         0     .0625
     p75 |  .1904762  .1666667  .1904762  .4433333  .1666667       .36  .3333333      .055        .5  .2592593
--------------------------------------------------------------------------------------------------------------

tabstat poolaccess poolsuspens poolconstit ///
poolbudget poolcompliance poolpolicy poolagenda poolfinal pooling, stats ///
(mean p50 cv min max p25 p75)


   stats |  poolac~s  poolsu~s  poolco~t  poolbu~t  poolco~e  poolpo~y  poolag~a  poolfi~l   pooling
---------+------------------------------------------------------------------------------------------
    mean |  .3547155  .1434128  .2025431  .4387036   .301579  .3109233  .2540259  .3299332  .2919796
     p50 |       .33         0      .165       .33      .165       .25   .226875    .31625  .2853125
      cv |  .6926042  1.807738  .9755037  .7183873  1.085996  .6919419  .7457856  .6152751  .6323573
     min |         0         0         0         0         0         0         0         0         0
     max |         1         1       .83         1         1         1  .7629167       .79  .7283334
     p25 |      .125         0    .04125      .165         0      .165  .0833333  .1666667     .1375
     p75 |        .5       .25       .33       .66       .58      .375  .3866667     .5375  .4254167
----------------------------------------------------------------------------------------------------

outreg2 using del.doc, replace sum(log) keep(delaccess delsuspens delconstit ///
delbudget delfincompl delpolicy del_agenda del_final DS_sum_st delegation) dec(3)

outreg2 using DP_volIII_sept2017, replace sum(log) keep( poolaccess poolsuspens poolconstit ///
poolbudget poolcompliance  poolpolicy poolagenda poolfinal pooling) dec(3)

**Keep only the variables you need for each table, otherwise matsize error message
*keep delaccess delsuspens delconstit delbudget delfincompl delpolicy  del_agenda  del_final DS_sum_st delegation
outreg2 using xxx1.doc, replace sum(detail) eqkeep(mean p50 cv min max p25 p75) dec(3)
*keep poolaccess poolconstit poolsuspens poolcompliance poolbudget poolpolicy poolagenda poolfinal pooling
outreg2 using xxx1.doc, replace sum(detail) eqkeep(mean p50 cv min max p25 p75) dec(3)

*NOTE: beanplot figures made with R (contact Besir Ceka)
 

 *APPENDIX 3: MIA TABLES
 ///DROPPING DUPLICATE OBSERVATIONS IN ORDER TO CREATE FINAL TABLES AND FIGURES
**MIA tables for delegation
preserve
by ionumber (year), sort : gen delegation_diff=1 if delegation[_n-1]!=delegation[_n]
drop if delegation_diff !=1
sort ioname year
br ioname inception year delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
 DS_sum_st delegation

*generate MIA tables automatically
tostring year, generate (years) 
by ionumber (year), sort: gen years1=year[_n+1]
by ionumber (year), sort: gen   years2=years1-1
tostring years2, generate (years22)
replace years22="2010" if years22=="."

gen str8 dash ="-"
by ionumber (year), sort: gen  str10 years3=years+dash+years22
replace years3=years if years22==years
replace years3="1974-1991" if ioname=="COMECON"&years3=="1974-2010" 
replace years3="1974-1976" if ioname=="EAC1"&years3=="1974-2010" 

gen ioname1=ioname
replace ioname1="" if ioname[_n-1]==ioname

sort ioname year
br ioname1  years3 delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
 del_agenda  del_final DS_sum_st delegation6


**MIA tables for pooling
restore
by ionumber (year), sort : gen pooling_diff=1 if pooling2[_n-1]!=pooling2[_n]
drop if pooling_diff !=1
sort ioname year

*generate MIA tables automatically
tostring year, generate (years) 
by ionumber (year), sort: gen years1=year[_n+1]
by ionumber (year), sort: gen   years2=years1-1
tostring years2, generate (years22)
replace years22="2010" if years22=="." 

gen str8 dash ="-"
by ionumber (year), sort: gen  str10 years3=years+dash+years22
replace years3=years if years22==years
replace years3="1959-1991" if ioname=="COMECON"&years3=="1959-2010" 
replace years3="1967-1976" if ioname=="EAC1"&years3=="1967-2010" 

gen ioname1=ioname
replace ioname1="" if ioname[_n-1]==ioname

sort ioname year
br ioname1  years3 poolaccess poolsuspens poolconstit poolbudget poolcompliance poolpolicy poolagenda poolfinal pooling2



